@@ -27,8 +27,8 @@ import re
 import csv
 import traceback
 import unicodedata
-import way
-from time import clock
+import modules.way as way
+#from time import clock
 import time
 
 DIRECTIONS_FILTER_CSV_PATH = 'data/directions_filter.csv'
@@ -547,6 +547,9 @@ class route(ranaModule):
     # save
     self.directions = directions
 
+  def getDirections(self):
+    return self.directions
+
   def filterDirections(self, directions):
     """
     filter directions according to substitution rules (specified by a CSV file)
